@@ -22,8 +22,13 @@
 
 #include <giomm/appinfo.h>
 #include <giomm/asyncresult.h>
+#include <giomm/bufferedinputstream.h>
+#include <giomm/bufferedoutputstream.h>
 #include <giomm/cancellable.h>
+#include <giomm/datainputstream.h>
+#include <giomm/dataoutputstream.h>
 #include <giomm/drive.h>
+#include <giomm/enums.h>
 #include <giomm/error.h>
 #include <giomm/fileattributeinfolist.h>
 #include <giomm/fileenumerator.h>
@@ -34,10 +39,12 @@
 #include <giomm/filemonitor.h>
 #include <giomm/fileoutputstream.h>
 #include <giomm/filterinputstream.h>
+#include <giomm/filteroutputstream.h>
 #include <giomm/icon.h>
 #include <giomm/init.h>
 #include <giomm/inputstream.h>
 #include <giomm/loadableicon.h>
+#include <giomm/memoryinputstream.h>
 #include <giomm/mount.h>
 #include <giomm/mountoperation.h>
 #include <giomm/outputstream.h>
@@ -45,6 +52,7 @@
 #include <giomm/simpleasyncresult.h>
 #include <giomm/volume.h>
 #include <giomm/volumemonitor.h>
+#include <giomm/contenttype.h>
 
 #endif /* #ifndef _GIOMM_H */
 
